@@ -6,21 +6,19 @@ import stat
 import sys
 import unittest
 from unittest import mock
+import zoneinfo
 
 import configobj
 import pytest
-import pytz
 
 import certbot
-from certbot import configuration
 from certbot import errors
 from certbot._internal.storage import ALL_FOUR
+from certbot._internal import san
 from certbot.compat import filesystem
 from certbot.compat import os
 import certbot.tests.util as test_util
 
-CERT = test_util.load_cert('cert_512.pem')
-
 
 def unlink_all(rc_object):
     """Unlink all four items associated with this RenewableCert."""
@@ -97,16 +95,22 @@ class RelevantValuesTest(unittest.TestCase):
         namespace = cli.prepare_and_parse_args(PLUGINS, [
             '--allow-subset-of-names',
             '--authenticator', 'apache',
+            '--preferred-profile', 'fancyprofile',
         ])
         expected_relevant_values = {
             'server': constants.CLI_DEFAULTS['server'],
             'key_type': 'ecdsa',
             'allow_subset_of_names': True,
             'authenticator': 'apache',
+            'preferred_profile': 'fancyprofile',
         }
 
         assert relevant_values(namespace) == expected_relevant_values
 
+    def test_with_required_profile(self):
+        self.values["required_profile"] = "shortlived"
+        expected_relevant_values = self.values.copy()
+        assert self._call(self.values) == expected_relevant_values
 
 class BaseRenewableCertTest(test_util.ConfigTestCase):
     """Base class for setting up Renewable Cert tests.
@@ -429,62 +433,17 @@ class RenewableCertTests(BaseRenewableCertTest):
             else:
                 assert not self.test_rc.has_pending_deployment()
 
-    def test_names(self):
+    def test_sans(self):
         # Trying the current version
         self._write_out_kind("cert", 12, test_util.load_vector("cert-san_512.pem"))
 
-        assert self.test_rc.names() == \
-                         ["example.com", "www.example.com"]
+        assert self.test_rc.sans() == \
+                         [san.DNSName("example.com"), san.DNSName("www.example.com")]
 
         # Trying missing cert
         os.unlink(self.test_rc.cert)
         with pytest.raises(errors.CertStorageError):
-            self.test_rc.names()
-
-    @mock.patch.object(configuration.NamespaceConfig, 'set_by_user')
-    @mock.patch("certbot._internal.storage.datetime")
-    def test_time_interval_judgments(self, mock_datetime, mock_set_by_user):
-        """Test should_autorenew() on the basis of expiry time windows."""
-        test_cert = test_util.load_vector("cert_512.pem")
-
-        self._write_out_ex_kinds()
-
-        self.test_rc.update_all_links_to(12)
-        with open(self.test_rc.cert, "wb") as f:
-            f.write(test_cert)
-        self.test_rc.update_all_links_to(11)
-        with open(self.test_rc.cert, "wb") as f:
-            f.write(test_cert)
-
-        mock_datetime.timedelta = datetime.timedelta
-        mock_set_by_user.return_value = False
-        self.test_rc.configuration["renewalparams"] = {}
-
-        for (current_time, interval, result) in [
-                # 2014-12-13 12:00:00+00:00 (about 5 days prior to expiry)
-                # Times that should result in autorenewal/autodeployment
-                (1418472000, "2 months", True), (1418472000, "1 week", True),
-                # Times that should not
-                (1418472000, "4 days", False), (1418472000, "2 days", False),
-                # 2009-05-01 12:00:00+00:00 (about 5 years prior to expiry)
-                # Times that should result in autorenewal/autodeployment
-                (1241179200, "7 years", True),
-                (1241179200, "11 years 2 months", True),
-                # Times that should not
-                (1241179200, "8 hours", False), (1241179200, "2 days", False),
-                (1241179200, "40 days", False), (1241179200, "9 months", False),
-                # 2015-01-01 (after expiry has already happened, so all
-                #            intervals should cause autorenewal/autodeployment)
-                (1420070400, "0 seconds", True),
-                (1420070400, "10 seconds", True),
-                (1420070400, "10 minutes", True),
-                (1420070400, "10 weeks", True), (1420070400, "10 months", True),
-                (1420070400, "10 years", True), (1420070400, "99 months", True),
-        ]:
-            sometime = datetime.datetime.fromtimestamp(current_time, pytz.UTC)
-            mock_datetime.datetime.now.return_value = sometime
-            self.test_rc.configuration["renew_before_expiry"] = interval
-            assert self.test_rc.should_autorenew() == result
+            self.test_rc.sans()
 
     def test_autorenewal_is_enabled(self):
         self.test_rc.configuration["renewalparams"] = {}
@@ -495,23 +454,6 @@ class RenewableCertTests(BaseRenewableCertTest):
         self.test_rc.configuration["renewalparams"]["autorenew"] = "False"
         assert not self.test_rc.autorenewal_is_enabled()
 
-    @mock.patch.object(configuration.NamespaceConfig, 'set_by_user')
-    @mock.patch("certbot._internal.storage.RenewableCert.ocsp_revoked")
-    def test_should_autorenew(self, mock_ocsp, mock_set_by_user):
-        """Test should_autorenew on the basis of reasons other than
-        expiry time window."""
-        mock_set_by_user.return_value = False
-        # Autorenewal turned off
-        self.test_rc.configuration["renewalparams"] = {"autorenew": "False"}
-        assert not self.test_rc.should_autorenew()
-        self.test_rc.configuration["renewalparams"]["autorenew"] = "True"
-        for kind in ALL_FOUR:
-            self._write_out_kind(kind, 12)
-        # Mandatory renewal on the basis of OCSP revocation
-        mock_ocsp.return_value = True
-        assert self.test_rc.should_autorenew()
-        mock_ocsp.return_value = False
-
     @mock.patch("certbot._internal.storage.relevant_values")
     def test_save_successor(self, mock_rv):
         # Mock relevant_values() to claim that all values are relevant here
@@ -739,14 +681,13 @@ class RenewableCertTests(BaseRenewableCertTest):
         from certbot._internal import storage
 
         # this month has 30 days, and the next year is a leap year
-        time_1 = datetime.datetime(2003, 11, 20, 11, 59, 21, tzinfo=pytz.UTC)
+        time_1 = datetime.datetime(2003, 11, 20, 11, 59, 21, tzinfo=datetime.timezone.utc)
 
         # this month has 31 days, and the next year is not a leap year
-        time_2 = datetime.datetime(2012, 10, 18, 21, 31, 16, tzinfo=pytz.UTC)
+        time_2 = datetime.datetime(2012, 10, 18, 21, 31, 16, tzinfo=datetime.timezone.utc)
 
         # in different time zone (GMT+8)
-        time_3 = pytz.timezone('Asia/Shanghai').fromutc(
-            datetime.datetime(2015, 10, 26, 22, 25, 41))
+        time_3 = datetime.datetime(2015, 10, 26, 22, 25, 41, tzinfo=zoneinfo.ZoneInfo('Asia/Shanghai'))
 
         intended = {
             (time_1, ""): time_1,
@@ -805,26 +746,27 @@ class RenewableCertTests(BaseRenewableCertTest):
         with pytest.raises(errors.CertStorageError):
             storage.RenewableCert(self.config_file.filename, self.config)
 
-    def test_write_renewal_config(self):
+    def test_atomic_rewrite(self):
         # Mostly tested by the process of creating and updating lineages,
         # but we can test that this successfully creates files, removes
-        # unneeded items, and preserves comments.
+        # unneeded items, preserves permissions, and preserves comments.
         temp = os.path.join(self.config.config_dir, "sample-file")
-        temp2 = os.path.join(self.config.config_dir, "sample-file.new")
         with open(temp, "w") as f:
             f.write("[renewalparams]\nuseful = value # A useful value\n"
                     "useless = value # Not needed\n")
         filesystem.chmod(temp, 0o640)
-        target = {}
+        perms = stat.S_IMODE(os.lstat(temp).st_mode)
+        config = configobj.ConfigObj()
         for x in ALL_FOUR:
-            target[x] = "somewhere"
-        archive_dir = "the_archive"
-        relevant_data = {"useful": "new_value"}
+            config[x] = "somewhere"
+        config["version"] = certbot.__version__
+        config["archive_dir"] = "the_archive"
+        config["renewalparams"] = {"useful": "new_value"}
 
         from certbot._internal import storage
-        storage.write_renewal_config(temp, temp2, archive_dir, target, relevant_data)
+        storage.atomic_rewrite(temp, config)
 
-        with open(temp2, "r") as f:
+        with open(temp, "r") as f:
             content = f.read()
         # useful value was updated
         assert "useful = new_value" in content
@@ -835,8 +777,7 @@ class RenewableCertTests(BaseRenewableCertTest):
         # check version was stored
         assert "version = {0}".format(certbot.__version__) in content
         # ensure permissions are copied
-        assert stat.S_IMODE(os.lstat(temp).st_mode) == \
-                         stat.S_IMODE(os.lstat(temp2).st_mode)
+        assert stat.S_IMODE(os.lstat(temp).st_mode) == perms
 
     def test_truncate(self):
         # It should not do anything when there's less than 5 cert history
